#### ${ _("Credit Transactions") }

${ _("Code") } | ${ _("Date") } | ${ _("Description") } | ${ _("Value") }
% for item in report.client.get_credit_transactions():
${ item.identifier } | ${ format_date(item.paid_date) } | ${ item.description } | ${ (not item.is_outpayment() and '-' or '') } ${ format_price(item.value) }
% endfor
|  | ${ _("Total:") } | ${ format_price(report.client.credit_account_balance) }